==> haskell-hspec-wai-json-0.9.0-146-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-G4dG7sA2UqRALAYf9Wn8gM
key: hspec-wai-json-0.9.0-G4dG7sA2UqRALAYf9Wn8gM
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: a3cc6cb07931942c31518fe98f70b7af
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-G4dG7sA2UqRALAYf9Wn8gM
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    aeson-qq-0.8.2-BaaxVzNCzldJ8GPgEwzxnx base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.0-GKreMgsyLsr2t93nBKS1zO template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.9.0-148-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai-json
version: 0.9.0
id: hspec-wai-json-0.9.0-5azj3hGRMjGHDTTsoBXTXj
key: hspec-wai-json-0.9.0-5azj3hGRMjGHDTTsoBXTXj
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Testing JSON APIs with hspec-wai
description:
    Testing JSON APIs with hspec-wai
category: Testing
abi: 2d01a09a333219fb0f92001e7207d1f3
exposed: True
exposed-modules:
    Test.Hspec.Wai.JSON
hidden-modules: Paths_hspec_wai_json
import-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/hspec-wai-json-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/hspec-wai-json-0.9.0
hs-libraries: HShspec-wai-json-0.9.0-5azj3hGRMjGHDTTsoBXTXj
depends:
    aeson-1.4.2.0-BdBVLho0lrWC4iPoef6lEw
    aeson-qq-0.8.2-BaaxVzNCzldJ8GPgEwzxnx base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    hspec-wai-0.9.0-206b0el9Gqp2psIhvMidZJ template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
